@@ -15,6 +15,11 @@ selectVars <- function(.data, keep) {
 
     keep <- paste(keep, collapse = ", ")
 
+    if (is_survey(.data) && !inherits(.data, "tbl_svy")) {
+        .data <- srvyr::as_survey(.data)
+        dataname <- glue::glue("{dataname} %>% srvyr::as_survey()")
+    }
+
     exp <- ~.DATA %>% dplyr::select(.KEEP)
     exp <- replaceVars(exp,
         .DATA = dataname,
